@@ -34,13 +34,6 @@ def edit(card, mode):
 	if mode not in implemented_modes:
 		return
 
-	if mode == 'a':
-		card.make_auxfile('front')
-		card.make_auxfile('back')
-
-	assert 'front' in card.auxfiles
-	assert 'back' in card.auxfiles
-
 	# we are going to run vim...
 	vim_cmd = ['vim']
 	vim_cmd += [card.path/'front']
