@@ -19,11 +19,6 @@ def edit(card, mode):
 	# possible modes are a, e, f, b, *
 	assert mode in ['a','e','f','t','b','*']
 
-	if mode == 'a':
-		card.make_auxfile('lines')
-
-	assert 'lines' in card.auxfiles
-
 	# we are going to run vim...
 	vim_cmd = ['vim']
 	vim_cmd += [card.path/'lines']
