@@ -9,7 +9,7 @@ from vinca.lib.video import DisplayImage
 from vinca.lib.audio import Recording
 from vinca.lib.terminal import AlternateScreen
 
-def default_str(card):
+def make_string(card):
 	f = ' / '.join((card.path / 'front').read_text().splitlines())
 	b = ' / '.join((card.path / 'back').read_text().splitlines())
 	return f + ' | ' + b
@@ -21,6 +21,8 @@ def review(card,mode):
 		# front text
 		front = (card.path / 'front').read_text()
 		print(re.sub(r'\{.*?\}', colorize, front))
+		tags_str = '    '.join(['['+t.replace('_',' ')+']' for t in card.tags])  # TODO show tags only if requested
+		print(ansi['light'] + tags_str + ansi['reset'])
 
 		# front media
 		with DisplayImage(card.path/'image_front'), Recording(card.path/'audio_front'):
