@@ -18,6 +18,5 @@ def review(card,mode):
 	
 	return char
 
-def default_str(card):
-	
+def make_string(card):
 	return (card.path / 'lines').read_text().replace('\n',' / ')
