@@ -11,10 +11,11 @@ def schedule(card):
 		card.set_due_date(today)
 		return 0
 
+	if card.last_grade == 0:
+		due_date = today + 7*day
 	if card.last_grade == 1:
 		card.set_due_date(today)
 		return 5
-
 	if card.last_grade == 2:
 		due_date = today + max(day, card.last_interval / 2)
 	elif card.last_grade == 3:
